@@ -470,7 +470,7 @@ TDebugLoggerBase::~TDebugLoggerBase()
 {
   // make sure debug is finalized
   DebugFinalizeOutput();
-  // make sure eventually left-over history elements are erased
+  // make sure possibly left-over history elements are erased
   while (fBlockHistory) {
     TBlockLevel *bl=fBlockHistory;
     fBlockHistory=bl->fNext;
@@ -492,7 +492,7 @@ lineartime_t TDebugLoggerBase::getSystemNowAs(timecontext_t aContext)
 // install outputter
 void TDebugLoggerBase::installOutput(TDbgOut *aDbgOutP)
 {
-  // get rid of eventually installed previous outputter
+  // get rid of possibly installed previous outputter
   if (fDbgOutP) delete fDbgOutP;
   fDbgOutP=aDbgOutP;
 } // TDebugLoggerBase::installOutput
@@ -559,6 +559,16 @@ void TDebugLoggerBase::DebugPrintf(uInt32 aDbgMask, cAppCharP aFormat, ...)
 } // TDebugLoggerBase::DebugVPrintf
 
 
+// open new Block without attribute list
+void TDebugLoggerBase::DebugOpenBlock(cAppCharP aBlockName, cAppCharP aBlockTitle, bool aCollapsed)
+{
+  // we need a format and debug not completely off
+  if (getMask() && aBlockName) {
+    DebugOpenBlock(aBlockName,aBlockTitle,aCollapsed,NULL);
+  }
+} // TDebugLoggerBase::DebugOpenBlock
+
+
 // open new Block with attribute list, printf style
 void TDebugLoggerBase::DebugOpenBlock(cAppCharP aBlockName, cAppCharP aBlockTitle, bool aCollapsed, cAppCharP aBlockFmt, ...)
 {
@@ -598,16 +608,6 @@ void TDebugLoggerBase::DebugOpenBlockCollapsed(cAppCharP aBlockName, cAppCharP a
 } // TDebugLoggerBase::DebugOpenBlockCollapsed
 
 
-// open new Block without attribute list
-void TDebugLoggerBase::DebugOpenBlock(cAppCharP aBlockName, cAppCharP aBlockTitle, bool aCollapsed)
-{
-  // we need a format and debug not completely off
-  if (getMask() && aBlockName) {
-    DebugVOpenBlock(aBlockName,aBlockTitle,aCollapsed,NULL,NULL);
-  }
-} // TDebugLoggerBase::DebugOpenBlock
-
-
 // output text to debug channel
 void TDebugLoggerBase::DebugPuts(uInt32 aDbgMask, cAppCharP aText, stringSize aTextSize, bool aPreFormatted)
 {
@@ -890,7 +890,7 @@ void TDebugLoggerBase::DebugVOpenBlock(cAppCharP aBlockName, cAppCharP aBlockTit
     // create Block line on current indent level
     string bl;
     string ts;
-    // - preamble, eventually with timestamp
+    // - preamble, possibly with timestamp
     bool withTime = fDbgOptionsP->fTimestampStructure;
     if (withTime)
       StringObjTimestamp(ts,getSystemNowAs(TCTX_SYSTEM));
@@ -1099,7 +1099,7 @@ void TDebugLoggerBase::internalCloseBlocks(cAppCharP aBlockName, cAppCharP aClos
     }
     // now close topmost Block
     string ts,bl;
-    // - get time if needed and eventually put it within indented block
+    // - get time if needed and possibly put it within indented block
     if (withTime) {
       StringObjTimestamp(ts,getSystemNowAs(TCTX_SYSTEM));
       // for XML, the time must be shown before the close tag on a separate line
@@ -1378,7 +1378,7 @@ TDebugLoggerBase *TDebugLogger::getThreadLogger(bool aCreateNew)
   // unknown subthread
   if (fMainThreadID==0) {
     // no current mainthread, let subthread write to main log
-    // Note: this makes sure log info eventually trailing the DebugThreadOutputDone()
+    // Note: this makes sure log info possibly trailing the DebugThreadOutputDone()
     //       also lands in the main log. This is not critical - the only thing that must be
     //       ensured is that starting new threads is made only with DebugDefineMainThread set.
     return this;
@@ -1516,7 +1516,7 @@ void TDebugLogger::DebugThreadOutputDone(bool aRemoveIt)
 
 
 // Used to regain control as main thread (e.g. for the next request of a session which
-// eventually occurs from another thread).
+// possibly occurs from another thread).
 void TDebugLogger::DebugDefineMainThread(void)
 {
   #ifdef MULTI_THREAD_SUPPORT
