@@ -168,9 +168,9 @@ TSyError TSettingsKeyImpl::GetValueByID(
   // get native type of value (and check validity of ID - invalid IDs must return VALTYPE_UNKNOWN)
   uInt16 valType = GetValueType(aID);
   if (valType==VALTYPE_UNKNOWN) return DB_NotFound;
-  // direct return in case requested type matches native type
+  // direct return in case requested type matches native type or raw data (VALTYPE_BUF) is requested
   if (
-    (aValType == VALTYPE_BUF) ||
+    (aValType == VALTYPE_BUF) || // we want raw buffer data
     ((valType == aValType) &&
      (valType != VALTYPE_TEXT || (fCharSet==chs_utf8 && fLineEndMode==lem_cstr)) &&
      (valType != VALTYPE_TIME64 || ((fTimeMode & TMODE_MODEMASK)==TMODE_LINEARTIME)) )
@@ -183,21 +183,39 @@ TSyError TSettingsKeyImpl::GetValueByID(
       }
       else {
         // low level text routines do not set terminators for simplicity, so make sure we have one here
-        sta=GetValueInternal(aID,aArrayIndex,aBuffer,aBufSize-1,aValSize);
-        // make sure we have a NUL terminator
-        ((appCharP)aBuffer)[aBufSize-1]=0; // ultimate terminator
+        // - request only max one char less than buf can hold, so we always have room for a terminator
+        sta = GetValueInternal(aID,aArrayIndex,aBuffer,aBufSize-1,aValSize);
+        // - make sure we have a NUL terminator at the very end of the buffer in all cases
+        ((appCharP)aBuffer)[aBufSize-1] = 0; // ultimate terminator
+        // - also make sure we have a terminator at the end of the actual string
         if (sta==LOCERR_OK && aValSize<aBufSize)
-          ((appCharP)aBuffer)[aValSize]=0;
-        // return LOCERR_TRUNCATED if ok but buffer is not large enough
+          ((appCharP)aBuffer)[aValSize] = 0;
+        // signal LOCERR_TRUNCATED if ok, but buffer is not large enough
         if (sta==LOCERR_OK && aValSize>aBufSize-1) {
           sta = LOCERR_TRUNCATED;
-          aValSize=aBufSize-1; // return actual size, not untruncated one
+          aValSize = aBufSize-1; // return actual size, not untruncated one
         }
         return sta;
       }
     }
-    else
-      return GetValueInternal(aID,aArrayIndex,aBuffer,aBufSize,aValSize);
+    else {
+    	// non-text, simply return value
+      sta = GetValueInternal(aID,aArrayIndex,aBuffer,aBufSize,aValSize);
+      if (sta==LOCERR_OK && aBufSize && aBuffer && aValSize>aBufSize) {
+      	// not only measuring size, check for truncation
+      	if (aValType==VALTYPE_BUF) {
+        	// in case of buffer, we call this "truncated" (we don't know if the result is usable or not, depends on data itself)
+	        sta = LOCERR_TRUNCATED;
+	      	aValSize = aBufSize; // return actual size, not untruncated one
+        }
+        else {
+        	// in other cases, too small buffer makes result unusable, so we don't call it "truncated"
+          // AND: we return the needed buffer size
+        	sta = LOCERR_BUFTOOSMALL;
+        }
+      }
+      return sta;
+    }
   }
   // some kind of conversion needed
   // - get native size of value first
@@ -316,7 +334,7 @@ TSyError TSettingsKeyImpl::GetValueByID(
               aBufSize>0 ? aBufSize-2 : 0 // max output size (but no limit if measuring actual size)
             ))
               sta = LOCERR_TRUNCATED;
-            // return (eventually truncated) size
+            // return (possibly truncated) size
             aValSize=convStr.size();
             // this will be added as part of the content, and gives a 16bit NUL terminator
             convStr+=(char)0;
@@ -332,7 +350,7 @@ TSyError TSettingsKeyImpl::GetValueByID(
               aBufSize>0 ? aBufSize-1 : 0 // max output size (but no limit if measuring actual size)
             ))
               sta = LOCERR_TRUNCATED;
-            // return (eventually truncated) size
+            // return (possibly truncated) size
             aValSize=convStr.size();
           }
           // if requested, return value into buffer
@@ -406,9 +424,10 @@ TSyError TSettingsKeyImpl::SetValueByID(
         appendUTF16AsUTF8((uInt16 *)aBuffer,aValSize/2,fBigEndian,convStr, true, true);
       }
       else {
-        appendStringAsUTF8((cAppCharP)aBuffer, convStr, fCharSet, lem_cstr, true);
+      	string s; s.assign((cAppCharP)aBuffer,aValSize);
+        appendStringAsUTF8(s.c_str(), convStr, fCharSet, lem_cstr, true);
       }
-      // eventually convert text to native
+      // possibly convert text to native
       switch (valType) {
         case VALTYPE_TIME64:
           // convert text to internal time format
@@ -486,20 +505,26 @@ TSyError TSettingsKeyImpl::SetValueByID(
       tempInt = *((sInt64 *)aBuffer);
     intConv:
       // convert integer into native type
-      bP = &tempInt; // re-use as temp buffer
+      union {
+        sInt64 buffer64;
+        sInt32 buffer32;
+        sInt16 buffer16;
+        sInt8  buffer8;
+      } buffer;
+      bP = &buffer;
       switch (valType) {
         case VALTYPE_INT8:
-          siz=1; *((sInt8 *)bP) = tempInt;
+          siz=1; buffer.buffer8 = tempInt;
           break;
         case VALTYPE_INT16:
-          siz=2; *((sInt16 *)bP) = tempInt;
+          siz=2; buffer.buffer16 = tempInt;
           break;
         case VALTYPE_INT32:
-          siz=4; *((sInt32 *)bP) = tempInt;
+          siz=4; buffer.buffer32 = tempInt;
           break;
         case VALTYPE_INT64:
         case VALTYPE_TIME64: // native timestamp
-          siz=8; *((sInt64 *)bP) = tempInt;
+          siz=8; buffer.buffer64 = tempInt;
           break;
         default:
           // other types (like text) cannot set as integer
@@ -695,7 +720,8 @@ TSyError TConfigVarKey::SetValueInternal(
   cAppPointer aBuffer, memSize aValSize
 ) {
 	if (!aBuffer) return LOCERR_WRONGUSAGE; // cannot handle NULL values
-  if (!fEngineInterfaceP->getSyncAppBase()->setConfigVar(fVarName.c_str(),(cAppCharP)aBuffer))
+  string v; v.assign((cAppCharP)aBuffer,(size_t)aValSize); // copy because input could be unterminated string
+  if (!fEngineInterfaceP->getSyncAppBase()->setConfigVar(fVarName.c_str(),v.c_str()))
     return DB_NotFound;
   return LOCERR_OK;
 } // TConfigVarKey::SetValueInternal
@@ -735,6 +761,17 @@ TSyError TStructFieldsKey::returnInt(sInt32 aInt, memSize aIntSize, appPointer a
 } // returnInt
 
 
+TSyError TStructFieldsKey::returnLineartime(lineartime_t aTime, appPointer aBuffer, memSize aBufSize, memSize &aValSize)
+{
+	aValSize=sizeof(lineartime_t);
+  if (aBufSize==0) return LOCERR_OK; // measuring size
+  if (aBufSize<aValSize) return LOCERR_BUFTOOSMALL;
+  *((lineartime_t *)aBuffer) = aTime;
+  return LOCERR_OK;
+}
+
+
+
 
 // get value's ID (e.g. internal index)
 sInt32 TStructFieldsKey::GetValueID(cAppCharP aName)
@@ -861,8 +898,10 @@ TSyError TStructFieldsKey::SetValueInternal(
   else
     siz=aValSize;
   // copy data into struct
-  if (fldinfoP->valType==VALTYPE_TEXT_OBFUS)
-    assignMangledToCString((appCharP)valPtr, (cAppCharP)aBuffer, fldinfoP->valSiz, true); // always use entire buffer and fill it with garbage beyond end of actual data
+  if (fldinfoP->valType==VALTYPE_TEXT_OBFUS) {
+  	string v; v.assign((cAppCharP)aBuffer,aValSize);
+    assignMangledToCString((appCharP)valPtr, v.c_str(), fldinfoP->valSiz, true); // always use entire buffer and fill it with garbage beyond end of actual data
+  }
   else
     memcpy(valPtr,aBuffer,siz);
   // - struct modified, signal that (for derivates that might want to save the record on close)
@@ -1225,6 +1264,7 @@ TSyError TEngineInterface::SessionStep (SessionH aSessionH, uInt16 &aStepCmd, TE
 TSyError TEngineInterface::GetSyncMLBuffer(SessionH aSessionH, bool aForSend, appPointer &aBuffer, memSize &aBufSize)
 {
   Ret_t rc;
+  MemSize_t bufSz; // Note: this is SML_TK definition of memsize!
   // get SML instance for this session (note that "session" could be a SAN checker as well)
   InstanceID_t myInstance = getSmlInstanceOfSession(aSessionH);
   if (myInstance==0)
@@ -1235,16 +1275,18 @@ TSyError TEngineInterface::GetSyncMLBuffer(SessionH aSessionH, bool aForSend, ap
     rc=smlLockReadBuffer(
       myInstance,
       (unsigned char **)&aBuffer, // receives address of buffer containing SyncML to send
-      (long *)&aBufSize // receives size of SyncML to send
+      &bufSz // receives size of SyncML to send
     );
+    aBufSize = bufSz;
   }
   else {
     // we want to write the SyncML buffer
     rc=smlLockWriteBuffer(
       myInstance,
       (unsigned char **)&aBuffer, // receives address of buffer where received SyncML can be put
-      (long *)&aBufSize // capacity of the buffer
+      &bufSz // capacity of the buffer
     );
+    aBufSize = bufSz;
   }
   // check error
   if (rc!=SML_ERR_OK)
@@ -1643,108 +1685,199 @@ TSyError TEngineInterface::SetValueByID(
 // DBApi-like access to datastores
 // ===============================
 
-TSyError TEngineInterface::StartDataRead( CContext ac, cAppCharP lastToken, cAppCharP resumeToken )
+TSyError TEngineInterface::StartDataRead(SessionH aSessionH, cAppCharP lastToken, cAppCharP resumeToken)
 {
-  #error "complete these for real DBAPI_TUNNEL_SUPPORT (or do not define DBAPI_TUNNEL_SUPPORT to switch it off)"
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelStartDataRead(lastToken,resumeToken);
 } // StartDataRead
 
 
-TSyError TEngineInterface::ReadNextItem ( CContext ac, ItemID  aID, appCharP *aItemData,
-                                                       sInt32 *aStatus, bool  aFirst )
+TSyError TEngineInterface::ReadNextItem(SessionH aSessionH, ItemID  aID, appCharP *aItemData, sInt32 *aStatus, bool  aFirst)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelReadNextItem(aID,aItemData,aStatus,aFirst);
 } // ReadNextItem
 
 
-TSyError TEngineInterface::ReadItem( CContext ac, cItemID aID, appCharP *aItemData )
+TSyError TEngineInterface::ReadItem(SessionH aSessionH, cItemID aID, appCharP *aItemData)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelReadItem(aID,aItemData);
 } // ReadItem
 
 
-TSyError TEngineInterface::EndDataRead( CContext ac )
+TSyError TEngineInterface::EndDataRead(SessionH aSessionH)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelEndDataRead();
 } // EndDataRead
 
 
-TSyError TEngineInterface::StartDataWrite( CContext ac )
+TSyError TEngineInterface::StartDataWrite(SessionH aSessionH)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelStartDataWrite();
 } // StartDataWrite
 
 
-TSyError TEngineInterface::InsertItem( CContext ac, cAppCharP aItemData, cItemID aID )
+TSyError TEngineInterface::InsertItem(SessionH aSessionH, cAppCharP aItemData, ItemID aID)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelInsertItem(aItemData,aID);
 } // InsertItem
 
 
-TSyError TEngineInterface::UpdateItem( CContext ac, cAppCharP aItemData, cItemID   aID,
-                                                                          ItemID updID )
+TSyError TEngineInterface::UpdateItem(SessionH aSessionH, cAppCharP aItemData, cItemID aID, ItemID updID )
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelUpdateItem(aItemData,aID,updID);
 } // UpdateItem
 
 
-TSyError TEngineInterface::MoveItem( CContext ac, cItemID aID, cAppCharP newParID )
+TSyError TEngineInterface::MoveItem(SessionH aSessionH, cItemID aID, cAppCharP newParID)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelMoveItem(aID,newParID);
 } // MoveItem
 
 
-TSyError TEngineInterface::DeleteItem( CContext ac, cItemID aID )
+TSyError TEngineInterface::DeleteItem(SessionH aSessionH, cItemID aID)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelDeleteItem(aID);
 } // DeleteItem
 
 
-TSyError TEngineInterface::EndDataWrite( CContext ac, bool success, appCharP *newToken )
+TSyError TEngineInterface::EndDataWrite(SessionH aSessionH, bool success, appCharP *newToken)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelEndDataWrite(success,newToken);
 } // EndDataWrite
 
 
-void     TEngineInterface::DisposeObj( CContext ac, void* memory )
+void TEngineInterface::DisposeObj(SessionH aSessionH, void* memory)
 {
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return; // need properly opened tunnel session/datastore
+  return ds->TunnelDisposeObj(memory);
 } // DisposeObj
 
 
 // ---- asKey ----
-TSyError TEngineInterface::ReadNextItemAsKey( CContext ac, ItemID  aID, KeyH aItemKey,
-                                                           sInt32 *aStatus,   bool aFirst )
+TSyError TEngineInterface::ReadNextItemAsKey(SessionH aSessionH, ItemID  aID, KeyH aItemKey, sInt32 *aStatus, bool aFirst)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelReadNextItemAsKey(aID,aItemKey,aStatus,aFirst);
 } // ReadNextItemAsKey
 
 
-TSyError TEngineInterface::ReadItemAsKey( CContext ac, cItemID aID, KeyH aItemKey )
+TSyError TEngineInterface::ReadItemAsKey(SessionH aSessionH, cItemID aID, KeyH aItemKey)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelReadItemAsKey(aID,aItemKey);
 } // ReadItemAsKey
 
 
-TSyError TEngineInterface::InsertItemAsKey( CContext ac, KeyH aItemKey, cItemID aID )
+TSyError TEngineInterface::InsertItemAsKey(SessionH aSessionH, KeyH aItemKey, ItemID aID)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelInsertItemAsKey(aItemKey,aID);
 } // InsertItemAsKey
 
 
-TSyError TEngineInterface::UpdateItemAsKey( CContext ac, KeyH aItemKey, cItemID   aID,
-                                                                         ItemID updID )
+TSyError TEngineInterface::UpdateItemAsKey(SessionH aSessionH, KeyH aItemKey, cItemID aID, ItemID updID)
 {
-  return DB_Error;
+	TLocalEngineDS *ds = reinterpret_cast<TSyncSession *>(aSessionH)->getTunnelDS();
+  if (!ds) return LOCERR_WRONGUSAGE; // need properly opened tunnel session/datastore
+  return ds->TunnelUpdateItemAsKey(aItemKey,aID,updID);
 } // UpdateItemAsKey
 
 #endif // DBAPI_TUNNEL_SUPPORT
 
+TSyError TEngineInterface::debugPuts(cAppCharP aFile, int aLine, cAppCharP aFunction,
+                                     int aDbgLevel, cAppCharP aPrefix,
+                                     cAppCharP aText)
+{
+  #if defined(SYDEBUG)
+  getSyncAppBase()->getDbgLogger()->DebugPuts(/* aFile, aLine, aFunction, aPrefix */
+                                              aDbgLevel, aText);
+  return 0;
+  #else
+  return LOCERR_NOTIMP;
+  #endif
+} // debugPuts
 
+#ifdef ENGINE_LIBRARY
 #ifndef SIMPLE_LINKING
 
 // Callback "factory" function implementation
 
-// Main entry point
+static TSyError internal_ConnectEngine(
+	bool aIsServer,
+  UI_Call_In *aCIP,
+  uInt16 aCallbackVersion, // if==0, engine creates new aCI
+  CVersion *aEngVersionP,
+  CVersion aPrgVersion,
+  uInt16 aDebugFlags
+)  
+{
+  // create new engine
+  TEngineModuleBase *engine = NULL;
+  TSyError err = LOCERR_OK;
+  if (aIsServer) {
+  	#ifdef SYSYNC_SERVER
+    engine = newServerEngine();
+    #else
+    err = LOCERR_WRONGUSAGE;
+    #endif
+  }
+  else {
+  	#ifdef SYSYNC_CLIENT
+    engine = newClientEngine();
+    #else
+    err = LOCERR_WRONGUSAGE;
+    #endif
+  }
+  if (err==LOCERR_OK) {
+    // connect the engine
+    if (aCallbackVersion!=0) {
+      // valid aCIP passed in
+      // - flag static
+      engine->fCIisStatic= true;
+      // - prepare callback and pass to engine
+      (*aCIP)->callbackVersion = aCallbackVersion; // fill in the outside callback version
+      engine->fCI = *aCIP;                         // engine uses the structure provided by the uiapp
+      // - connect the engine
+      err = engine->Connect("", aPrgVersion, aDebugFlags);
+    }
+    else {
+    	// no aCIP passed, let engine create one
+      // - connect engine
+		  err = engine->Connect("", aPrgVersion, aDebugFlags);
+      // - get CI from engine
+			*aCIP = engine->fCI;
+    }
+    // - get the version
+    if (aEngVersionP) *aEngVersionP = Plugin_Version(0);
+  }
+  return   err;	
+} // internal_ConnectEngine
+
+
+// Client engine main entry point
 TSyError SYSYNC_EXTERNAL(ConnectEngine)(
   UI_Call_In *aCI,
   CVersion   *aEngVersion,
@@ -1752,13 +1885,7 @@ TSyError SYSYNC_EXTERNAL(ConnectEngine)(
   uInt16      aDebugFlags
 )
 {
-  // create new engine
-  TEngineModuleBase *engine = newEngine();
-  // connect callback
-  TSyError err= engine->Connect("", aPrgVersion, aDebugFlags);
-  *aCI        = engine->fCI;
-  *aEngVersion= Plugin_Version(0);
-  return   err;
+	return internal_ConnectEngine(false, aCI, 0, aEngVersion, aPrgVersion, aDebugFlags);
 } // ConnectEngine
 
 
@@ -1771,21 +1898,38 @@ TSyError SYSYNC_EXTERNAL(ConnectEngineS)(
   uInt16      aDebugFlags
 )
 {
-  // create new engine
-  TEngineModuleBase *engine = newEngine();
-  engine->fCIisStatic= true;
-
-  // connect callback
-                aCI->callbackVersion= aCallbackVersion;
-  engine->fCI = aCI;
-  TSyError err= engine->Connect( "", aPrgVersion, aDebugFlags );
-  *aEngVersion= Plugin_Version(0);
-  return   err;
+	return internal_ConnectEngine(false, &aCI, aCallbackVersion, aEngVersion, aPrgVersion, aDebugFlags);
 } // ConnectEngineS
 
 
-/* Entry point to disconnect engine */
-TSyError SYSYNC_EXTERNAL(DisconnectEngine)( UI_Call_In aCI )
+// Server engine main entry point
+TSyError SYSYNC_EXTERNAL_SRV(ConnectEngine)(
+  UI_Call_In *aCI,
+  CVersion   *aEngVersion,
+  CVersion    aPrgVersion,
+  uInt16      aDebugFlags
+)
+{
+	return internal_ConnectEngine(true, aCI, 0, aEngVersion, aPrgVersion, aDebugFlags);
+} // ConnectEngine
+
+
+// The same, but coming in with a valid <aCI> */
+TSyError SYSYNC_EXTERNAL_SRV(ConnectEngineS)(
+  UI_Call_In  aCI,
+  uInt16      aCallbackVersion,
+  CVersion   *aEngVersion,
+  CVersion    aPrgVersion,
+  uInt16      aDebugFlags
+)
+{
+	return internal_ConnectEngine(true, &aCI, aCallbackVersion, aEngVersion, aPrgVersion, aDebugFlags);
+} // ConnectEngineS
+
+
+
+
+static TSyError internal_DisconnectEngine(UI_Call_In aCI)
 {
   TSyError err= LOCERR_OK;
 
@@ -1794,7 +1938,6 @@ TSyError SYSYNC_EXTERNAL(DisconnectEngine)( UI_Call_In aCI )
     TEngineModuleBase *engine = static_cast<TEngineModuleBase *>(aCI->thisBase);
     err= engine->Disconnect();
     aCI->thisBase= NULL; // no longer valid
-
     // delete the engine (this also deletes the callback!)
     SYSYNC_TRY {
       delete engine;
@@ -1804,13 +1947,26 @@ TSyError SYSYNC_EXTERNAL(DisconnectEngine)( UI_Call_In aCI )
     SYSYNC_ENDCATCH
     // done
   } // if
-
   return err;
-} // DisconnectEngine
+} // internal_DisconnectEngine
 
 
+/* Entry point to disconnect client engine */
+TSyError SYSYNC_EXTERNAL(DisconnectEngine)(UI_Call_In aCI)
+{
+	return internal_DisconnectEngine(aCI);
+}
 
-#endif // SIMPLE_LINKING
+
+/* Entry point to disconnect server engine */
+TSyError SYSYNC_EXTERNAL_SRV(DisconnectEngine)(UI_Call_In aCI)
+{
+	return internal_DisconnectEngine(aCI);
+}
+
+
+#endif // not SIMPLE_LINKING
+#endif // ENGINE_LIBRARY
 
 
 } // namespace sysync
