@@ -889,7 +889,7 @@ bool endDateFromCount(
     {
       case 'W':
         LOGDEBUGPRINTFX(aLogP,DBG_PARSE+DBG_EXOTIC,("RRULE2toInternal() simple weekly calc"));
-        // v1 end date calc, we need to take into account eventual masks, so result must be end of interval, not just start date+interval
+        // v1 end date calc, we need to take into account possible masks, so result must be end of interval, not just start date+interval
         // weekly: end date is last day of target week
         until=dtstart+((ivrep*DaysOfWeek-startwday+6)*linearDateToTimeFactor);
         return true;
@@ -1028,7 +1028,7 @@ bool endDateFromCount(
           // occurrence interval can be at most 4 years in the future (safety abort)
           while (newYearsPassed<=4) {
             if (firstmask & ((uInt64)1<<(startmonth-1))) {
-              // eventually found an occurrence
+              // possibly found an occurrence
               // - is an occurrence only if that day exists in the month
               if (startday<=lastday) {
                 cnt--; // count it
@@ -1224,7 +1224,7 @@ void initRRuleExpansion(
   if (es.lastmask==0 && es.firstmask) {
   	fieldinteger_t m = es.firstmask;
     es.singleFMaskBit = 0;
-  	while((m & 1)==0) { m>>=1; es.singleFMaskBit++; } // calculate bit number 
+  	while((m & 1)==0) { m>>=1; es.singleFMaskBit++; } // calculate bit number of next set bit
     if (m & ~1) es.singleFMaskBit = -1; // more bits to come - reset again
   }
   // init expansion parameters
@@ -1255,22 +1255,13 @@ void initRRuleExpansion(
 }
 
 
-// negative aAtLeastDays allowed only with aModulo==1 (because of undefined % operator for negatives - altough it is normally truncate towards zero = remainder)
-static void adjustCursor(TRRuleExpandStatus &es, lineardate_t aAtLeastDays, sInt16 aModulo=1)
+// advance cursor by given number of days
+static void adjustCursor(TRRuleExpandStatus &es, lineardate_t aDays)
 {
-	lineardate_t days = 0;
-  days = aAtLeastDays; // default to simply add days
-  if (aModulo>1) {
-    // we need to make sure remainder is 0 and advance extra
-    lineardate_t extradays = aAtLeastDays % aModulo;
-    if (extradays!=0) {
-      days += aModulo-extradays;
-    }
-  }
   // now days = number of days to advance
-  es.cursor += days*linearDateToTimeFactor;
+  es.cursor += aDays*linearDateToTimeFactor;
   // adjust weekday
-  es.cursorWDay += days % DaysPerWk;
+  es.cursorWDay += aDays % DaysPerWk;
   if (es.cursorWDay<0) es.cursorWDay += DaysPerWk;
   else if (es.cursorWDay>=DaysPerWk) es.cursorWDay -= DaysPerWk;    
   #ifdef SYNTHESIS_UNIT_TEST
@@ -1281,6 +1272,21 @@ static void adjustCursor(TRRuleExpandStatus &es, lineardate_t aAtLeastDays, sInt
   #endif
 }
 
+
+static lineardate_t makeMultiple(lineardate_t d, sInt16 aMultiple, sInt16 aMaxRemainder=0)
+{
+  if (aMultiple>1) {
+    // we need to make sure remainder is 0 and advance extra
+    lineardate_t r = d % aMultiple; // remainder
+    if (r>aMaxRemainder) {
+			// round up to next multiple
+    	d += aMultiple - r;
+    }
+  }
+	return d;	
+}
+
+
 // simple and fast cursor increment
 static void incCursor(TRRuleExpandStatus &es)
 {
@@ -1337,7 +1343,7 @@ lineartime_t getNextOccurrence(TRRuleExpandStatus &es)
   	// Daily: can be calculated directly
     if (!es.started) {
     	// calculate first occurrence
-    	adjustCursor(es, es.expansionStartDayOffset, es.interval); // move cursor to first day
+    	adjustCursor(es, makeMultiple(es.expansionStartDayOffset, es.interval)); // move cursor to first day
     }
     else {
       // calculate next occurrence
@@ -1349,15 +1355,18 @@ lineartime_t getNextOccurrence(TRRuleExpandStatus &es)
     // so recurrence starting at a Thu, scheduled for every two weeks on Mo and Thu will have:
     // 1st week: Thu, 2nd week: nothing, 3rd week: Mo,Thu, 4rd week: nothing, 5th week: Mo,Thu...
   	if (!es.started) {
-      // - make sure we have a mask
+      // make sure we have a mask
       if (es.firstmask==0)
         es.firstmask = 1<<es.cursorWDay; // set start day in mask
-      // - advance cursor to first day of expansion period
-      sInt16 woffs = es.cursorWDay-es.weekstart; // how many days back to next week start
-      if (woffs<0) woffs+=DaysPerWk; // we want to go BACK to next week start
-      adjustCursor(es, -woffs, 1); // back to previous start of week
-    	adjustCursor(es, es.expansionStartDayOffset, es.interval*DaysPerWk); // advance by intervals
-      adjustCursor(es, woffs, 1); // back to start weekday
+      // advance cursor to first day of expansion period
+      // - go back to start of very first week covered by the recurrence
+      sInt16 woffs = es.cursorWDay-es.weekstart; // how many days back to next week start from dtstart
+      if (woffs<0) woffs+=DaysPerWk; // we want to go BACK to previous week start
+      adjustCursor(es, -woffs); // back to previous start of week (=start of first week covered by recurrence)
+      lineardate_t d = es.expansionStartDayOffset+woffs; // days from beginning of first week to beginning day of expansion
+      // if we exceed reach of mask in current interval, round up to beginning of next interval
+      d = makeMultiple(d,es.interval*DaysPerWk,DaysPerWk-1); // expand into next interval if needed 
+    	adjustCursor(es, d); // now advance cursor to 
 	    if (expansionEnd(es)) goto done; // could by beyond current expanding scope due to interval jump 
 		}
     // calculate first/next occurrence (if not first occurrence, do not check initially but advance first)
@@ -1870,7 +1879,7 @@ bool RRULE2toInternal(
           }
         }
         // check if anything is behind endindex
-        if (endIndex == string::npos && startIndex < byday.length() - 1)
+        if (endIndex == string::npos && startIndex < byday.length())
         {
           endIndex = byday.length();
           if (!setWeekday(byday, firstmask, lastmask, startIndex, endIndex, false))
@@ -1916,7 +1925,7 @@ bool RRULE2toInternal(
           }
         }
         // check if anything is behind endindex
-        if (endIndex == string::npos && startIndex < byday.length() - 1)
+        if (endIndex == string::npos && startIndex < byday.length())
         {
           endIndex = byday.length();
           if (!setWeekday(byday, firstmask, lastmask, startIndex, endIndex, false))
@@ -1957,7 +1966,7 @@ bool RRULE2toInternal(
           }
         }
         // check if anything is behind endindex
-        if (endIndex == string::npos && startIndex < bymonthday.length() - 1)
+        if (endIndex == string::npos && startIndex < bymonthday.length())
         {
           endIndex = bymonthday.length();
           if (!setMonthDay(bymonthday, firstmask, lastmask, startIndex, endIndex))
@@ -1986,7 +1995,7 @@ bool RRULE2toInternal(
           }
         }
         // check if anything is behind endindex
-        if (endIndex == string::npos && startIndex < byday.length() - 1)
+        if (endIndex == string::npos && startIndex < byday.length())
         {
           endIndex = byday.length();
           if (!setWeekday(byday, firstmask, lastmask, startIndex, endIndex, true))
