@@ -185,33 +185,43 @@ TSuperDataStore::TSuperDataStore(TSuperDSConfig *aDSConfigP, TSyncSession *aSess
     SYSYNC_THROW(TSyncException(DEBUGTEXT("TSuperDataStore::TSuperDataStore called with NULL config","lds1")));
   // reset first
   InternalResetDataStore();
-  // create links to subdatastores
-  TSubDSConfigList::iterator pos;
-  TSubDatastoreLink link;
-  for(pos=aDSConfigP->fSubDatastores.begin();pos!=aDSConfigP->fSubDatastores.end();pos++) {
-    // start not yet pending
-    link.fStartPending=false;
-    // set link to subdatastore link config
-    link.fDSLinkConfigP=*pos;
-    // find actual datastore by "handle" (= config pointer)
-    link.fDatastoreLinkP=aSessionP->findLocalDataStore(link.fDSLinkConfigP->fLinkedDSConfigP);
-    // if actual datastore does not yet exist, create it now. This can be
-    // the case for clients, where datastores are only instantiated when
-    // directly addressed by a SyncRequest (which will not happen for
-    // subdatastores normally)
-    if (!link.fDatastoreLinkP) {
-      // add
-      link.fDatastoreLinkP=aSessionP->addLocalDataStore(link.fDSLinkConfigP->fLinkedDSConfigP);
+  // for server, all configured subdatastores are automatically linked in
+  // (for client, only those that are active will be linked in at dsSetClientParams() time)
+  if (IS_SERVER) {
+    // create links to subdatastores
+    TSubDSConfigList::iterator pos;
+    for(pos=aDSConfigP->fSubDatastores.begin();pos!=aDSConfigP->fSubDatastores.end();pos++) {
+  		// add link
+      addSubDatastoreLink(*pos,NULL); // search datastore
     }
-    // save link
-    fSubDSLinks.push_back(link);
   }
-  // Important: We need to get the iterator now again, as the implicit
-  //   iterator init via InternalResetDataStore() is invalid because the list was empty then.
-  fCurrentGenDSPos=fSubDSLinks.begin();
 } // TSuperDataStore::TSuperDataStore
 
 
+void TSuperDataStore::addSubDatastoreLink(TSubDSLinkConfig *aDSLinkConfigP, TLocalEngineDS *aDatastoreP)
+{
+  TSubDatastoreLink link;
+  // start not yet pending
+  link.fStartPending = false;
+  // set link to subdatastore's config
+  link.fDSLinkConfigP = aDSLinkConfigP;
+  if (aDatastoreP)
+    link.fDatastoreLinkP = aDatastoreP; // we already know the datastore (for client, it might not yet be in session list of datastores)
+  else
+  	link.fDatastoreLinkP = fSessionP->findLocalDataStore(link.fDSLinkConfigP->fLinkedDSConfigP); // find actual datastore by "handle" (= config pointer)
+  // make sure datastore is instantiated
+  if (!link.fDatastoreLinkP) {
+    // instantiate now (should not happen on server, as all datastores are instantiated on a server anyway)
+    link.fDatastoreLinkP=fSessionP->addLocalDataStore(link.fDSLinkConfigP->fLinkedDSConfigP);
+  }
+  // save link
+  fSubDSLinks.push_back(link);	
+  // Important: We need to get the iterator now again, in case the list was empty before
+  // (because the iterator set in InternalResetDataStore() is invalid because it was created for an empty list).
+  fCurrentGenDSPos=fSubDSLinks.begin();
+}
+
+
 void TSuperDataStore::InternalResetDataStore(void)
 {
   // init
@@ -285,21 +295,22 @@ TAlertCommand *TSuperDataStore::engProcessSyncAlert(
         aLastRemoteAnchor,      // last anchor of client
         aNextRemoteAnchor,      // next anchor of client
         aTargetURI,             // target URI as sent by remote, no processing at all
-        aIdentifyingTargetURI,  // target URI (without eventual CGI)
+        aIdentifyingTargetURI,  // target URI (without possible CGI)
         aTargetURIOptions,      // filtering CGI (NULL or empty if none)
         aTargetFilter,          // DS 1.2 filter, NULL if none
         aSourceURI,             // source URI
         substatus               // status that might be modified
       );
       if (subalertcmdP) {
-        // get rid of this, we don't need it
+        // get rid of this, we don't need it (server case only, client case does not generate an alert command here anyway)
         delete subalertcmdP;
       }
-      else {
+      // check if processing alert had a problem
+      if (substatus.getStatusCode()!=0) {
         // basic problem with one of the subdatastores
         // - propagate error code
         aStatusCommand.setStatusCode(substatus.getStatusCode());
-        // - cancel alert
+        // - no alert to send
         return NULL;
       }
       // this one is pending for start
@@ -314,7 +325,7 @@ TAlertCommand *TSuperDataStore::engProcessSyncAlert(
       aLastRemoteAnchor,      // last anchor of client
       aNextRemoteAnchor,      // next anchor of client
       aTargetURI,             // target URI as sent by remote, no processing at all
-      aIdentifyingTargetURI,  // target URI (without eventual CGI)
+      aIdentifyingTargetURI,  // target URI (without possible CGI)
       aTargetURIOptions,      // filtering CGI (NULL or empty if none)
       aTargetFilter,          // DS 1.2 filter, NULL if none
       aSourceURI,             // source URI
@@ -471,7 +482,7 @@ bool TSuperDataStore::engProcessSyncCmdEnd(bool &aQueueForLater)
 } // TSuperDataStore::engProcessSyncCmdEnd
 
 
-#ifndef SYSYNC_CLIENT
+#ifdef SYSYNC_SERVER
 
 // process map
 localstatus TSuperDataStore::engProcessMap(cAppCharP aRemoteID, cAppCharP aLocalID)
@@ -494,7 +505,7 @@ done:
   return sta;
 } // TSuperDataStore::engProcessMap
 
-#endif
+#endif // SYSYNC_SERVER
 
 
 // called to process incoming item operation
@@ -512,7 +523,7 @@ bool TSuperDataStore::engProcessRemoteItem(
 {
   bool regular=true;
   string datatext;
-  #ifndef SYSYNC_CLIENT
+  #ifdef SYSYNC_SERVER
   TSyncItem *itemcopyP;
   #endif
 
@@ -530,163 +541,180 @@ bool TSuperDataStore::engProcessRemoteItem(
   TSyncOperation sop=syncitemP->getSyncOp();
   string remid;
   TSubDSLinkList::iterator pos;
-  switch (sop) {
-    #ifndef SYSYNC_CLIENT
-    // Server case
-    case sop_wants_replace:
-    case sop_replace:
-    case sop_wants_add:
-    case sop_add:
-      // item has no local ID, we need to apply filters to item data
-      PDEBUGPRINTFX(DBG_DATA,("Checkin subdatastore filters to find where it belongs"));
-      linkP = findSubLinkByData(*syncitemP);
-      if (!linkP) goto nods;
-      PDEBUGPRINTFX(DBG_DATA,(
-        "Found item belongs to subdatastore '%s'",
-        linkP->fDatastoreLinkP->getName()
-      ));
-      // make sure item does not have a local ID (which would be wrong because of prefixes anyway)
-      syncitemP->clearLocalID();
-      // remembert because we might need it below for move-replace
-      remid=syncitemP->getRemoteID();
-      // let subdatastore process
-      regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
-      // now check if replace was treated as add, if yes, this indicates
-      // that this might be a move between subdatastores
-      if (
-        (sop==sop_replace || sop==sop_wants_replace) &&
-        !fSlowSync && aStatusCommand.getStatusCode()==201
-      ) {
-        // this is probably a move from another datastore by changing an attribute
-        // that dispatches datastores (such as a vEvent changed to a vToDo)
-        // - so we delete all items with this remote ID in all other datastores
-        PDEBUGPRINTFX(DBG_DATA,("Replace could be a move between subdatastores, trying to delete all items with same remoteID in other subdatastores"));
-        TSubDSLinkList::iterator pos;
-        TStatusCommand substatus(fSessionP);
-        for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
-          if (&(*pos) != linkP) {
-            // all but original datastore
-            substatus.setStatusCode(200);
-            itemcopyP = new TSyncItem();
-            // - only remote ID and syncop are relevant, leave everything else empty
-            itemcopyP->setRemoteID(remid.c_str());
-            itemcopyP->setSyncOp(sop_delete);
-            // - now try to delete. This might fail if replace above wasn't a move
-            //   itemcopyP is consumed
-            PDEBUGPRINTFX(DBG_DATA+DBG_DETAILS,(
-              "Trying to delete item with remoteID='%s' from subdatastore '%s'",
-              itemcopyP->getRemoteID(),
-              linkP->fDatastoreLinkP->getName()
-            ));
-            regular=pos->fDatastoreLinkP->engProcessRemoteItem(itemcopyP,substatus);
-            #ifdef SYDEBUG
-            if (regular) {
-              // deleted ok
-              PDEBUGPRINTFX(DBG_DATA,(
-                "Found item in '%s', deleted here (and moved to '%s')",
-                pos->fDatastoreLinkP->getName(),
-                linkP->fDatastoreLinkP->getName()
-              ));
-            }
-            #endif
-          }
-        }
-        PDEBUGPRINTFX(DBG_DATA,("End of (possible) move-replace between subdatastores"));
-        regular=true; // fully ok, no matter if delete above has succeeded or not
-      }
-      goto done;
-    case sop_archive_delete:
-    case sop_soft_delete:
-    case sop_delete:
-    case sop_copy:
-      // item has no local ID AND no data, only a remoteID:
-      // we must try to read item from all subdatastores by remoteID until
-      // one is found
-      // get an empty item of correct type to call logicRetrieveItemByID
-      itemcopyP = getLocalReceiveType()->newSyncItem(getRemoteSendType(),this);
-      // - only remote ID is relevant, leave everything else empty
-      itemcopyP->setRemoteID(syncitemP->getRemoteID());
-      // try to read item from all subdatastores
-      for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
-        linkP = &(*pos);
-        // always start with 200
-        aStatusCommand.setStatusCode(200);
-        // now try to read
-        PDEBUGPRINTFX(DBG_DATA+DBG_DETAILS,(
-          "Trying to read item by remoteID='%s' from subdatastore '%s' to see if it is there",
-          itemcopyP->getRemoteID(),
+  #ifdef SYSYNC_SERVER
+  if (IS_SERVER) {
+    switch (sop) {
+      // Server case
+      case sop_wants_replace:
+      case sop_replace:
+      case sop_wants_add:
+      case sop_add:
+        // item has no local ID, we need to apply filters to item data
+        PDEBUGPRINTFX(DBG_DATA,("Checkin subdatastore filters to find where it belongs"));
+        linkP = findSubLinkByData(*syncitemP);
+        if (!linkP) goto nods;
+        PDEBUGPRINTFX(DBG_DATA,(
+          "Found item belongs to subdatastore '%s'",
           linkP->fDatastoreLinkP->getName()
         ));
-        regular=linkP->fDatastoreLinkP->logicRetrieveItemByID(*itemcopyP,aStatusCommand);
-        // must be ok AND not 404 (item not found)
-        if (regular && aStatusCommand.getStatusCode()!=404) {
-          PDEBUGPRINTFX(DBG_DATA,(
-            "Item found in subdatastore '%s', deleting it there",
+        // make sure item does not have a local ID (which would be wrong because of prefixes anyway)
+        syncitemP->clearLocalID();
+        // remembert because we might need it below for move-replace
+        remid=syncitemP->getRemoteID();
+        // let subdatastore process
+        regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
+        // now check if replace was treated as add, if yes, this indicates
+        // that this might be a move between subdatastores
+        if (
+          (sop==sop_replace || sop==sop_wants_replace) &&
+          !fSlowSync && aStatusCommand.getStatusCode()==201
+        ) {
+          // this is probably a move from another datastore by changing an attribute
+          // that dispatches datastores (such as a vEvent changed to a vToDo)
+          // - so we delete all items with this remote ID in all other datastores
+          PDEBUGPRINTFX(DBG_DATA,("Replace could be a move between subdatastores, trying to delete all items with same remoteID in other subdatastores"));
+          TStatusCommand substatus(fSessionP);
+          for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
+            if (&(*pos) != linkP) {
+              // all but original datastore
+              substatus.setStatusCode(200);
+              itemcopyP = new TSyncItem();
+              // - only remote ID and syncop are relevant, leave everything else empty
+              itemcopyP->setRemoteID(remid.c_str());
+              itemcopyP->setSyncOp(sop_delete);
+              // - now try to delete. This might fail if replace above wasn't a move
+              //   itemcopyP is consumed
+              PDEBUGPRINTFX(DBG_DATA+DBG_DETAILS,(
+                "Trying to delete item with remoteID='%s' from subdatastore '%s'",
+                itemcopyP->getRemoteID(),
+                linkP->fDatastoreLinkP->getName()
+              ));
+              regular=pos->fDatastoreLinkP->engProcessRemoteItem(itemcopyP,substatus);
+              #ifdef SYDEBUG
+              if (regular) {
+                // deleted ok
+                PDEBUGPRINTFX(DBG_DATA,(
+                  "Found item in '%s', deleted here (and moved to '%s')",
+                  pos->fDatastoreLinkP->getName(),
+                  linkP->fDatastoreLinkP->getName()
+                ));
+              }
+              #endif
+            }
+          }
+          PDEBUGPRINTFX(DBG_DATA,("End of (possible) move-replace between subdatastores"));
+          regular=true; // fully ok, no matter if delete above has succeeded or not
+        }
+        goto done;
+      case sop_archive_delete:
+      case sop_soft_delete:
+      case sop_delete:
+      case sop_copy:
+        // item has no local ID AND no data, only a remoteID:
+        // we must try to read item from all subdatastores by remoteID until
+        // one is found
+        // get an empty item of correct type to call logicRetrieveItemByID
+        itemcopyP = getLocalReceiveType()->newSyncItem(getRemoteSendType(),this);
+        // - only remote ID is relevant, leave everything else empty
+        itemcopyP->setRemoteID(syncitemP->getRemoteID());
+        // try to read item from all subdatastores
+        for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
+          linkP = &(*pos);
+          // always start with 200
+          aStatusCommand.setStatusCode(200);
+          // now try to read
+          PDEBUGPRINTFX(DBG_DATA+DBG_DETAILS,(
+            "Trying to read item by remoteID='%s' from subdatastore '%s' to see if it is there",
+            itemcopyP->getRemoteID(),
             linkP->fDatastoreLinkP->getName()
           ));
-          // now we can delete or copy, consuming original item
-          regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
-          // delete duplicated item as well
-          delete itemcopyP;
-          // done
-          regular=true;
-          goto done;
+          regular=linkP->fDatastoreLinkP->logicRetrieveItemByID(*itemcopyP,aStatusCommand);
+          // must be ok AND not 404 (item not found)
+          if (regular && aStatusCommand.getStatusCode()!=404) {
+            PDEBUGPRINTFX(DBG_DATA,(
+              "Item found in subdatastore '%s', deleting it there",
+              linkP->fDatastoreLinkP->getName()
+            ));
+            // now we can delete or copy, consuming original item
+            regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
+            // delete duplicated item as well
+            delete itemcopyP;
+            // done
+            regular=true;
+            goto done;
+          }
         }
-      }
-      // none of the datastores could process this item --> error
-      // - delete duplicated item
-      delete itemcopyP;
-      // - make sure delete reports 200 for incomplete-rollback-datastores
-      if (aStatusCommand.getStatusCode()==404 && sop!=sop_copy) {
-        // not finding an item for delete might be ok for remote...
-        if (fSessionP->getSessionConfig()->fDeletingGoneOK) {
-          // 404/410: item not found, could be because previous aborted session has
-          // already committed deletion of that item -> behave as if delete was ok
-          PDEBUGPRINTFX(DBG_DATA,("to-be-deleted item was not found, but do NOT report %hd",aStatusCommand.getStatusCode()));
-          aStatusCommand.setStatusCode(200);
+        // none of the datastores could process this item --> error
+        // - delete duplicated item
+        delete itemcopyP;
+        // - make sure delete reports 200 for incomplete-rollback-datastores
+        if (aStatusCommand.getStatusCode()==404 && sop!=sop_copy) {
+          // not finding an item for delete might be ok for remote...
+          if (fSessionP->getSessionConfig()->fDeletingGoneOK) {
+            // 404/410: item not found, could be because previous aborted session has
+            // already committed deletion of that item -> behave as if delete was ok
+            PDEBUGPRINTFX(DBG_DATA,("to-be-deleted item was not found, but do NOT report %hd",aStatusCommand.getStatusCode()));
+            aStatusCommand.setStatusCode(200);
+          }
+          // ...but it is a internal irregularity, fall thru to return false
         }
-        // ...but it is a internal irregularity, fall thru to return false
-      }
-      // is an internal irregularity
-      regular=false;
-      goto done;
-    #else
-    // Client case
-    case sop_wants_replace:
-    case sop_replace:
-    case sop_archive_delete:
-    case sop_soft_delete:
-    case sop_delete:
-    case sop_copy:
-      // item has local ID, we can find datastore by prefix
-      linkP = findSubLinkByLocalID(syncitemP->getLocalID());
-      if (!linkP) goto nods;
-      // remove prefix before letting subdatastore process it
-      syncitemP->fLocalID.erase(0,linkP->fDSLinkConfigP->fGUIDPrefix.size());
-      // now let subdatastore process
-      regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
-      goto done;
-    case sop_wants_add:
-    case sop_add:
-      // item has no local ID, we need to apply filters to item data
-      linkP = findSubLinkByData(*syncitemP);
-      if (!linkP) goto nods;
-      // make sure item does not have a local ID (which would be wrong because of prefixes anyway)
-      syncitemP->clearLocalID();
-      // let subdatastore process
-      regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
-      goto done;
-    #endif
-    default:
-    nods:
-      // no datastore or unknown command, general DB error
-      aStatusCommand.setStatusCode(510);
-      PDEBUGPRINTFX(DBG_ERROR,("TSuperDataStore::processRemoteItem Fatal: Item cannot be processed by any subdatastore"));
-      // consume item
-      delete syncitemP;
-      regular=false;
-      goto done;
-  } // switch
+        // is an internal irregularity
+        regular=false;
+        goto done;
+    case sop_reference_only:
+    case sop_move:
+    case sop_none:
+    case numSyncOperations:
+      // nothing to do or shouldn't happen
+      break;
+    } // switch
+  } // server
+  #endif // SYSYNC_SERVER
+  #ifdef SYSYNC_CLIENT
+  if (IS_CLIENT) {
+    switch (sop) {
+      // Client case
+      case sop_wants_replace:
+      case sop_replace:
+      case sop_archive_delete:
+      case sop_soft_delete:
+      case sop_delete:
+      case sop_copy:
+        // item has local ID, we can find datastore by prefix
+        linkP = findSubLinkByLocalID(syncitemP->getLocalID());
+        if (!linkP) goto nods;
+        // remove prefix before letting subdatastore process it
+        syncitemP->fLocalID.erase(0,linkP->fDSLinkConfigP->fGUIDPrefix.size());
+        // now let subdatastore process
+        regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
+        goto done;
+      case sop_wants_add:
+      case sop_add:
+        // item has no local ID, we need to apply filters to item data
+        linkP = findSubLinkByData(*syncitemP);
+        if (!linkP) goto nods;
+        // make sure item does not have a local ID (which would be wrong because of prefixes anyway)
+        syncitemP->clearLocalID();
+        // let subdatastore process
+        regular=linkP->fDatastoreLinkP->engProcessRemoteItem(syncitemP,aStatusCommand);
+        goto done;
+    case sop_reference_only:
+    case sop_move:
+    case sop_none:
+    case numSyncOperations:
+      // nothing to do or shouldn't happen
+      break;
+    } // switch
+  } // client
+  #endif // SYSYNC_CLIENT
+nods:
+  // no datastore or unknown command, general DB error
+  aStatusCommand.setStatusCode(510);
+  PDEBUGPRINTFX(DBG_ERROR,("TSuperDataStore::processRemoteItem Fatal: Item cannot be processed by any subdatastore"));
+  // consume item
+  delete syncitemP;
+  regular=false;
+  goto done;
 done:
   PDEBUGENDBLOCK("SuperProcessItem");
   return regular;
@@ -760,17 +788,14 @@ void TSuperDataStore::engFinishDataStoreSync(localstatus aErrorStatus)
 // ----------------------------------
 
 
-// Abstracts of TLocalEngineDS
-// ----------------------------
-
 
 // called at sync alert (before generating for client, after receiving for server)
 // - obtains combined anchor from subdatastores
 // - combines them into a common anchor (if possible)
 // - updates fFirstTimeSync as well
 localstatus TSuperDataStore::engInitSyncAnchors(
-  cAppCharP aDatastoreURI,      // local datastore URI
-  cAppCharP aRemoteDBID         // ID of remote datastore (to find session information in local DB)
+  cAppCharP aDatastoreURI,      // (Note: unused in superdatastore) local datastore URI
+  cAppCharP aRemoteDBID         // (Note: unused in superdatastore) ID of remote datastore (to find session information in local DB)
 )
 {
   bool allanchorsequal=true;
@@ -781,20 +806,19 @@ localstatus TSuperDataStore::engInitSyncAnchors(
   TSubDSLinkList::iterator pos;
   for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
     if (pos==fSubDSLinks.begin()) {
-      /* not needed, because engInitSyncAnchors() will be called only after all subdatastore's
-         engProcessSyncAlert() was called, which in turn contains a call to engInitSyncAnchors()
-         This means we can safely assume we have the fLastRemoteAnchor/fNextLocalAnchor info
-         ready here.
-         In fact, calling this here AGAIN had the effect that the state of the first
-         subdatastore would be set BACK to dssta_adminready (instead of the required dssta_syncmodestable,
-         and in turn when the first sync command arrived, it would be rejected with "SYNC received too early".
-      // init anchors of subdatastore
-      sta = pos->fDatastoreLinkP->engInitSyncAnchors(aDatastoreURI, aRemoteDBID);
-      if (sta!=LOCERR_OK)
-        break; // exit, we cannot init
-      */
-      // assign references of first datastore
-      // - this must be same from all subdatastores
+    	// Server case note:
+    	//   Subdatastore's engInitSyncAnchors() MUST NOT be called here, because this routine will
+      //   always be called after all subdatastore's engProcessSyncAlert() was called
+      //   which in turn contains a call to engInitSyncAnchors().
+      // Client case note:
+    	//   Subdatastore's engInitSyncAnchors() MUST NOT be called here, because this routine will
+      //   be called from TSuperDataStore::engPrepareClientSyncAlert() after iterating through
+      //   subdatastores and calling their engPrepareClientDSForAlert(), which in turn
+      //   contains a call to engInitSyncAnchors(). 
+      // This means we can safely assume we have the fLastRemoteAnchor/fNextLocalAnchor info
+      // ready here.
+      // - Assign references of first datastore
+			//   Note: remote anchor must be same from all subdatastores
       fLastRemoteAnchor=pos->fDatastoreLinkP->fLastRemoteAnchor;
       // - these are used from the first datastore, and might differ (a few seconds,
       //   that is) for other datastores
@@ -1023,7 +1047,7 @@ localstatus TSuperDataStore::engSaveSuspendState(bool aAnyway)
   if (aAnyway || !isAborted()) {
     // only save if DS 1.2 and supported by DB
     if ((fSessionP->getSyncMLVersion()>=syncml_vers_1_2) && dsResumeSupportedInDB()) {
-      PDEBUGBLOCKDESC("SuperSaveSuspendState","Saving state for suspend/resume");
+      PDEBUGBLOCKFMT(("SuperSaveSuspendState","Saving superdatastore suspend/resume state","superdatastore=%s",getName()));
       // save alert state
       fResumeAlertCode=fAlertCode;
       TSubDSLinkList::iterator pos;
@@ -1033,11 +1057,12 @@ localstatus TSuperDataStore::engSaveSuspendState(bool aAnyway)
           // save partial state if any
           if (pos->fDatastoreLinkP->fPartialItemState!=pi_state_save_outgoing) {
             // ONLY if we have no request for saving an outgoing item state already,
-            // we eventually need to save a pending incoming item
+            // we possibly need to save a pending incoming item
             // if there is an incompletely received item, let it update Partial Item (fPIxxx) state
             // (if it is an item of this datastore, that is).
-            if (fSessionP->fIncompleteDataCommandP)
+            if (fSessionP->fIncompleteDataCommandP) {
               fSessionP->fIncompleteDataCommandP->updatePartialItemState(pos->fDatastoreLinkP);
+            }
           }
           // mark ungenerated
           pos->fDatastoreLinkP->logicMarkOnlyUngeneratedForResume();
@@ -1046,7 +1071,7 @@ localstatus TSuperDataStore::engSaveSuspendState(bool aAnyway)
         /// localEngineDS, so markPendingForResume() on existing commands will
         /// directly reach the correct datastore
         /// @note markItemForResume() will get the localID as presented to
-        /// remote, that is in case of superdatastores prefixed that needs to be removed
+        /// remote, that is in case of superdatastores with prefixes that need to be removed
         fSessionP->markPendingForResume(this);
       }
       // let all subdatastores logicSaveResumeMarks() to make all this persistent
@@ -1063,7 +1088,7 @@ localstatus TSuperDataStore::engSaveSuspendState(bool aAnyway)
 } // TSuperDataStore::engSaveSuspendState
 
 
-#ifndef SYSYNC_CLIENT
+#ifdef SYSYNC_SERVER
 
 /// @brief called at end of request processing, should be used to save suspend state
 /// @note subdatastores don't do anything themselves, to make sure superds can make things happen in correct order
@@ -1142,26 +1167,82 @@ bool TSuperDataStore::engGenerateSyncCommands(
 
 #ifdef SYSYNC_CLIENT
 
-/* %%% not required - engClientStartOfSyncMessage() will be called for all local DS anyway,
-   and superDS will ALWAYS be called after contained subDS, as the superDS's definition
-   is always AFTER the contained subDS's definition in the config
-// called whenever outgoing Message of Sync Package starts
-// - Client will start Sync generation now, which means that subdatastores
-//   just set fSyncGenerationStarted=true (without actually creating a <sync>,
-//   and superdatastore creates a <sync> which will contain all add/delete/replace
-//   from all subdatastores (as generated by generateSyncCommands)
-void TSuperDataStore::engClientStartOfSyncMessage(void)
+// Client only: initialize Sync alert for datastore according to Parameters set with dsSetClientSyncParams()
+localstatus TSuperDataStore::engPrepareClientSyncAlert(void)
 {
-  // signal sync start to all subdatastores
+	localstatus sta;
+  
+  // not resuming by default
+	fResuming = false;
+  fResumeAlertCode = 0;
+	// prepare all subdatastores that were parametrized to participate in a sync by dsSetClientSyncParams()
   TSubDSLinkList::iterator pos;
   for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
-    pos->fDatastoreLinkP->engClientStartOfSyncMessage();
+  	TLocalEngineDS *dsP = pos->fDatastoreLinkP;
+    if (dsP->testState(dssta_clientparamset)) {
+    	// configured for sync, prepare for alert
+      sta = dsP->engPrepareClientDSForAlert();
+      if (sta!=LOCERR_OK)
+      	return sta; // error
+      // collect slow sync status
+      fSlowSync = fSlowSync || dsP->fSlowSync;
+    	// collect resume alert code
+      if (dsP->fResuming) {
+      	// subdatastore would like to resume
+        if (fResumeAlertCode!=0 && fResumeAlertCode!=dsP->fResumeAlertCode) {
+        	// different idea about what to resume -> can't resume
+          PDEBUGPRINTFX(DBG_ERROR,("subdatastores differ in resume alert code -> cancel resume of superdatastore"));
+          fResuming = false;
+        }
+        else {
+        	// resume is possible (but might be cancelled if another subdatastore disagrees 
+        	fResumeAlertCode = dsP->fResumeAlertCode;
+        	fResuming = true;
+        }
+      }
+    }
   }
-  // signal it to myself
-  TLocalEngineDS::engClientStartOfSyncMessage();
-} // TSuperDataStore::engClientStartOfSyncMessage
+  // now init my own anchors and firstsync state, which are a combination of my subdatastore's
+  sta = engInitSyncAnchors(NULL,NULL);
+  if (sta!=LOCERR_OK)
+    return sta; // error
+  // determine final resume state
+  if (fResuming) {
+    PDEBUGPRINTFX(DBG_PROTO,("Found suspended session with Alert Code = %hd for all subdatastores",fResumeAlertCode));
+	}
+  else {
+  	// superdatastore can't resume, cancel all subdatastore's resumes that might be set
+	  for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
+    	pos->fDatastoreLinkP->fResuming = false;
+    }
+  }
+  // all successful
+  return LOCERR_OK;
+} // TSuperDataStore::engPrepareClientSyncAlert
+  
+  
+
+// Init engine for client sync
+// - determine types to exchange
+// - make sync set ready
+localstatus TSuperDataStore::engInitForClientSync(void)
+{
+	localstatus sta = LOCERR_OK;
+  // first let all subdatastores init for sync
+  TSubDSLinkList::iterator pos;
+  for (pos=fSubDSLinks.begin();pos!=fSubDSLinks.end();pos++) {
+    sta = pos->fDatastoreLinkP->engInitDSForClientSync();
+    if (sta!=LOCERR_OK)
+    	return sta;
+  }
+  // now change my own state
+  return inherited::engInitDSForClientSync();
+} // TSuperDataStore::engInitForClientSync
+
+
+
+
 
-*/
 
 // Client only: returns number of unsent map items
 sInt32 TSuperDataStore::numUnsentMaps(void)
@@ -1183,7 +1264,7 @@ void TSuperDataStore::engMarkMapConfirmed(cAppCharP aLocalID, cAppCharP aRemoteI
   TSubDatastoreLink *linkP = findSubLinkByLocalID(aLocalID);
   if (linkP) {
     // pass to subdatastore with prefix removed
-    linkP->engMarkMapConfirmed(aLocalID+linkP->fDSLinkConfigP->fGUIDPrefix.size(),aRemoteID);
+    linkP->fDatastoreLinkP->engMarkMapConfirmed(aLocalID+linkP->fDSLinkConfigP->fGUIDPrefix.size(),aRemoteID);
   }
 } // TSuperDataStore::engMarkMapConfirmed
 
@@ -1191,10 +1272,7 @@ void TSuperDataStore::engMarkMapConfirmed(cAppCharP aLocalID, cAppCharP aRemoteI
 // - client only: called to generate Map items
 //   Returns true if now finished for this datastore
 //   also sets fState to dss_done when finished
-bool TSuperDataStore::engGenerateMapItems(
-  TMapCommand *aMapCommandP,
-  const char *aLocalIDPrefix
-)
+bool TSuperDataStore::engGenerateMapItems(TMapCommand *aMapCommandP, cAppCharP aLocalIDPrefix)
 {
   TSubDSLinkList::iterator pos=fSubDSLinks.begin();
   bool ok;
@@ -1206,9 +1284,9 @@ bool TSuperDataStore::engGenerateMapItems(
     if (pos==fSubDSLinks.end()) break; // done
     // create current prefix
     AssignString(prefix,aLocalIDPrefix);
-    prefix.append(fCurrentGenDSPos->fDSLinkConfigP->fGUIDPrefix);
+    prefix.append(pos->fDSLinkConfigP->fGUIDPrefix);
     // generate Map items
-    ok=pos->fDatastoreLinkP->engGenerateMapItems(TMapCommand *aMapCommandP,prefix.c_str());
+    ok=pos->fDatastoreLinkP->engGenerateMapItems(aMapCommandP,prefix.c_str());
     // exit if not yet finished with generating map items for this datastore
     if (!ok) {
       PDEBUGENDBLOCK("MapGenerate");
@@ -1219,22 +1297,26 @@ bool TSuperDataStore::engGenerateMapItems(
   } while(true);
   // done
   // we are done if state is syncdone (no more sync commands will occur)
-  if (fState==dss_syncsend) {
-    PDEBUGPRINTFX(DBG_PROTO,("TSuperDataStore: Finished sending chached Map items from previous session"))
-  }
-  else if (fState==dss_syncdone) {
-    fState=dss_done;
+  if (testState(dssta_dataaccessdone)) {
+    changeState(dssta_clientmapssent,true);
     PDEBUGPRINTFX(DBG_PROTO,("TSuperDataStore: Finished generating Map items, server has finished <sync>, we are done now"))
   }
+  #ifdef SYDEBUG
+  // else if we are not yet dssta_syncgendone -> this is the end of a early pending map send
+  else if (!dbgTestState(dssta_syncgendone)) {
+    PDEBUGPRINTFX(DBG_PROTO,("TSuperDataStore: Finished sending cached Map items from last session"))
+  }
+  // otherwise, we are not really finished with the maps yet (but with the current map command)
   else {
     PDEBUGPRINTFX(DBG_PROTO,("TSuperDataStore: Finished generating Map items for now, but server still sending <Sync>"))
   }
+  #endif
   PDEBUGENDBLOCK("MapGenerate");
   return true;
 } // TSuperDataStore::engGenerateMapItems
 
 
-#endif
+#endif // SYSYNC_CLIENT
 
 
 /* end of TSuperDataStore implementation */
