@@ -531,7 +531,7 @@ static bool tzcmp( const tz_entry &t, const tz_entry &tzi )
                        t.biasDST!=tzi.biasDST) return false;
   } // if
 
-  return tzi.ident != "-"  && // not removed
+  return !(tzi.ident=="-") && // not removed
                      ( idN ||
            t.ident.empty() ||
            t.ident == tzi.ident );
@@ -612,7 +612,7 @@ bool FoundTZ( const tz_entry &tc,
   tz_entry t = tc;
 
   if (!t.ident.empty() && // specific items will not contain more info
-       t.ident != " ") {
+     !(t.ident==" ")) {
     ClrDST  ( t );
   } // if
 
@@ -642,7 +642,7 @@ bool FoundTZ( const tz_entry &tc,
     for (pos= g->tzP.begin();
          pos!=g->tzP.end(); pos++) {
       if (j<0 &&
-          pos->ident != "-" && // element must not be removed
+          !(pos->ident=="-") && // element must not be removed
           tzcmp( t, *pos )) {
         aName= pos->name;
         ok   = true; break;
@@ -709,7 +709,7 @@ bool RemoveTZ( const tz_entry &t, GZones* g )
   TZList::iterator pos;
   for (pos= g->tzP.begin();
        pos!=g->tzP.end(); pos++) {
-    if (pos->ident != "-" && // element must not be removed
+    if (!(pos->ident=="-") && // element must not be removed
         tzcmp( t, *pos )) {
       pos->ident = "-";
     //gz()->tzP.erase( pos ); // do not remove it, keep it persistent
@@ -992,7 +992,7 @@ timecontext_t SelectTZ( TDaylightSavingZone zone, int bias, int biasDST, lineart
   bool dst, ok;
   bool withDST= zone!=EDstNone;
   timecontext_t t= tctx_tz_unknown;
-  bool special= false; // eventually needed true for NGage
+  bool special= false; // possibly needed true for NGage
 
   int  i; // go thru the whole list of time zones
   for (i=(int)tctx_tz_system+1; i<(int)tctx_numtimezones; i++) {
@@ -1258,7 +1258,7 @@ bool TzResolveMetaContext( timecontext_t &aContext, GZones* g )
 bool TzResolveContext( timecontext_t &aContext, lineartime_t aRefTime, bool aRefTimeUTC, GZones* g )
 {
   sInt32 offs;
-  // resolve eventual meta context (TCTX_SYSTEM at this time)
+  // resolve possible meta context (TCTX_SYSTEM at this time)
   if (!TzResolveMetaContext(aContext,g)) return false;
   // check if already an offset (non-symbolic)
   if (!TCTX_IS_TZ(aContext))
