@@ -29,14 +29,6 @@
 #include "sync_include.h"
 #include "sync_declarations.h"
 
-#ifdef JNI_SUPPORT
-  #ifdef MACOSX
-    #include <JavaVM/jni.h>
-  #else
-    #include <jni.h>
-  #endif
-#endif
-
 /* export prefix and suffix is dependent on platform and source language */
 #ifdef __cplusplus
   #define ENTRY_C extern "C"
@@ -46,6 +38,7 @@
 
 #if defined MACOSX
 	#define ENGINE_ENTRY ENTRY_C
+	#define ENGINE_ENTRY_CXX
 	
 	#ifdef __GNUC__
 	  #define ENTRY_ATTR __attribute__((visibility("default")))
@@ -56,14 +49,18 @@
   /* Visual Studio 2005 requires a specific entry point definition */
   /* This definition is empty for all other platforms */
   #define ENGINE_ENTRY ENTRY_C _declspec(dllexport)
+  #define ENGINE_ENTRY_CXX ENGINE_ENTRY
   #define ENTRY_ATTR
 #else
 	#define ENGINE_ENTRY ENTRY_C
+	#define ENGINE_ENTRY_CXX
 	#define ENTRY_ATTR
 #endif
 
 /* compose name of external symbols with C binding:
- * by default use parameter as-is (backwards compatibility),
+ * by default use parameter as-is (backwards compatibility) for client,
+ * and use "SySync_srv_" prefix for server.
+ * Newer builds usually use "SySync_" as prefix for client entry points.
  * can be changed in any file that is included before
  * this file
  */
@@ -71,6 +68,10 @@
 # define SYSYNC_EXTERNAL(_x) _x
 # define SYSYNC_PREFIX ""
 #endif
+#ifndef SYSYNC_EXTERNAL_SRV
+# define SYSYNC_EXTERNAL_SRV(_x) SySync_srv_ ## _x
+# define SYSYNC_PREFIX_SRV "SySync_srv_"
+#endif
 
 #ifdef __cplusplus
   namespace sysync {
@@ -88,15 +89,13 @@
 
 /* ---- Plugin support ---- */
 /* For the first versions, "N" is the platform identifier */
-/*      VP_Init               0x01000000   * V1.0.N.0 : Initial version                                 */
-/*      VP_1st                0x01000002   * V1.0.N.2 : 1st delivered version                           */
-/*      VP_Session_Login      0x01000003   * V1.0.N.3 : VAR_String for Session_Login: this version only */
-
 enum Version {
-  /** V1.0.N.4 : <engineVersion> param for "Module_PluginParams" */
-  VP_EngineVersionParam  = 0x01000004,
-  /** V1.0.N.5 : Callback version >= 2 supported                 */
-  VP_CB_Version2         = 0x01000005,
+/*VP_Init                  0x01000000   * V1.0.N.0 : Initial version */
+/*VP_1st                   0x01000002   * V1.0.N.2 : 1st delivered version */
+/*VP_Session_Login         0x01000003   * V1.0.N.3 : VAR_String for Session_Login: this version only */
+/*VP_EngineVersionParam    0x01000004   * V1.0.N.4 : <engineVersion> param for "Module_PluginParams" */
+/*VP_CB_Version2         = 0x01000005   * V1.0.N.5 : Callback version >= 2 supported */
+
   /** V1.0.N.6 : With new function "DeleteBlob"                  */
   VP_DeleteBlob          = 0x01000006,
   /** V1.0.N.7 : With new "scripting" function "AdaptItemData"   */
@@ -104,7 +103,7 @@ enum Version {
   /** V1.0.N.8 : Supports "InsertMapItem"                        */
   VP_InsertMapItem       = 0x01000008,
 
-/* From now on, the platform info can be found at he capabilities, "X" is a user defined build nr       */
+/* From now on, the platform info can be found at he capabilities, "X" is a user defined build nr */
   /** V1.0.5.X : "X": With customer defined plugin build number  */
   VP_NewBuildNumber      = 0x01000500,
   /** V1.0.6.X : Suspend/Resume extension for 'StartDataRead'    */
@@ -118,22 +117,22 @@ enum Version {
   /** V1.0.10.X: With enhanced "scripting" function "AdaptItem"  */
   VP_AdaptItem           = 0x01000a00,
 
-/* The new SyncML engine V2.9.X/V3.X.X runs best with versions from here onwards                        */
+/* The new SyncML engine V2.9.X/V3.X.X runs best with versions from here onwards */
   /** V1.1.0.X : Enhanced Plugin Info support: Server > 2.9.5.0  */
   VP_Plugin_Info         = 0x01010000,
   /** V1.2.1.X : With additional password mode + JNI adaption    */
   VP_MD5_Nonce_IN        = 0x01020100,
-/*      VP_061012             0x01020200   * V1.2.2.X : Released 12-Oct-06                              */
-/*      VP_061207             0x01030000   * V1.3.0.X : Released 07-Dec-06, Visual Studio support       */
+/*VP_061012                0x01020200   * V1.2.2.X : Released 12-Oct-06 */
+/*VP_061207                0x01030000   * V1.3.0.X : Released 07-Dec-06, Visual Studio support */
   /** V1.3.1.X : With UI function support                        */
   VP_UI_Support          = 0x01030100,
-/*      VP_070131             0x01030200   * V1.3.2.X : Released 31-Jan-07                              */
-/*      VP_070201             0x01030300   * V1.3.3.X : Released 01-Feb-07                              */
+/*VP_070131                0x01030200   * V1.3.2.X : Released 31-Jan-07 */
+/*VP_070201                0x01030300   * V1.3.3.X : Released 01-Feb-07 */
   /** V1.3.4.X : Java Callback with <cContext>                   */
   VP_Call_cContext       = 0x01030400,
   /** V1.3.4.X : Callback version >= 7 supported: UI / thisCB    */
   VP_CB_Version7         = 0x01030400,
-/*      VP_070212             0x01030600   * V1.3.6.X : Released 12-Feb-07                              */
+/*VP_070212                0x01030600   * V1.3.6.X : Released 12-Feb-07 */
   /** V1.3.8.X : Support for GlobContext structure               */
   VP_GlobContext         = 0x01030800,
   /** V1.3.9.X : Callback version >= 8 supported: extended UI    */
@@ -150,9 +149,16 @@ enum Version {
   VP_GlobMulti           = 0x01050100,
   /** V1.5.2.X : Callback version >= 11 supported: dbapi tunnel  */
   VP_CB_Version11        = 0x01050200,
-  /** V1.5.2.X : Current version, use 'Plugin_Version()'         */
-  VP_CurrentVersion      = 0x01050200,
-/*                                         *                                                            */
+  /** V1.6.0.X : Tunnel support                                  */
+  VP_Tunnel              = 0x01060000,
+  /** V1.6.1.X : Correct SetValue support                        */
+  VP_SetValue            = 0x01060100,
+  /** V1.6.2.X : 64 bit Java BLOB signature                      */
+  VP_BLOB_JSignature     = 0x01060200,
+/*VP_091221                0x01060200   * V1.6.2.X : Released 21-Dec-09 */
+  /** V1.7.0.X : Current version, use 'Plugin_Version()'         */
+  VP_CurrentVersion      = 0x01070000,
+
   /** -------- : Bad/undefined version                           */
   VP_BadVersion          = 0xffffffff,
 
@@ -245,6 +251,7 @@ enum Version {
 #define CA_JNI               "JNI"          /* Indicates, if plugin is based on JNI */
 #define CA_CSHARP            "C#"           /* Indicates, if plugin is based on C#  */
 #define CA_GUID              "GUID"         /* GUID */
+#define CA_Plugin            "PLUGIN"       /* Built-In plugin name */
 #define CA_GlobContext       "GlobContext"  /* The global context, if available */
 #define CA_ADMIN_Info        "ADMIN_Info"   /* Get ADMIN info as <name><SP>"ADMIN" with 'CreateContext' */
                                             /*   (supported for V1.3.7 and higher) */
@@ -278,13 +285,14 @@ enum Version {
 
 #define Plugin_UI            "plugin_ui"
 
+
 /* Compatibility to older versions */
-#define Plugin_Param_OLD     "plugin_param_OLD"
 #define Plugin_SE_Auth_OLD   "plugin_sessionauth_OLD"
 #define Plugin_DS_Data_OLD1  "plugin_datastore_OLD1"
 #define Plugin_DS_Data_OLD2  "plugin_datastore_OLD2"
 #define Plugin_DS_Admin_OLD  "plugin_datastoreadmin_OLD"
-#define Plugin_DS_Blob_OLD   "plugin_datablob_OLD"
+#define Plugin_DS_Blob_OLD1  "plugin_datablob_OLD1"
+#define Plugin_DS_Blob_OLD2  "plugin_datablob_OLD2"
 
 
 
@@ -340,13 +348,6 @@ struct GlobContext {
 #define GlobContext_JavaVM "JavaVM"
 
 
-/*! Wrapper for tunnel context callback */
-struct TunnelWrapper {
-  void*    tCB;
-  CContext tContext;
-};
-
-
 /*! Undefined function for place holder at 'ConnectFunctions', must have pointer size */
 #define XX (char *)-1
 
@@ -376,6 +377,8 @@ enum DebugFlags {
   DBG_PLUGIN_EXOT  = 0x0004,
   /** direct printf calls for test */ 
   DBG_PLUGIN_DIRECT= 0x0008,
+  /** GetValue/SetValue debugging */
+  DBG_GET_SET_VALUE= 0x0010,
   /** Default mask: all bits set */
   DBG_PLUGIN_ALL   = 0xffff,
 };
@@ -454,8 +457,8 @@ typedef TSyError (*Rd_ItemKFunc)( CContext ac,   cItemID aID,            KeyH  a
 typedef TSyError     (*EDR_Func)( CContext ac );
 
 typedef TSyError     (*SDW_Func)( CContext ac );
-typedef TSyError (*InsItemSFunc)( CContext ac, cAppCharP aItemData, cItemID aID );
-typedef TSyError (*InsItemKFunc)( CContext ac,      KeyH aItemKey,  cItemID aID );
+typedef TSyError (*InsItemSFunc)( CContext ac, cAppCharP aItemData,  ItemID aID );
+typedef TSyError (*InsItemKFunc)( CContext ac,      KeyH aItemKey,   ItemID aID );
 typedef TSyError (*UpdItemSFunc)( CContext ac, cAppCharP aItemData, cItemID aID,    ItemID    updID );
 typedef TSyError (*UpdItemKFunc)( CContext ac,      KeyH aItemKey,  cItemID aID,    ItemID    updID );
 typedef TSyError (*MovItem_Func)( CContext ac,                      cItemID aID, cAppCharP newParID );
@@ -610,6 +613,17 @@ typedef struct SDK_InterfaceType {
 
 
 
+/*! Wrapper for tunnel context callback */
+struct TunnelWrapper {
+  UI_Call_In tCB;          /* the Call-In reference */
+  SessionH   tContext;     /* the tunnel session context */
+  appCharP   tContextName; /* the tunnel session context name, needed for reopen in context */
+  KeyH       tItemKey;     /* an item key element for AsKey operations */
+  uInt16     tAfterWrite;  /* is true after first Insert/Update/Move/Delete */
+}; /* Tunnelwrapper */
+
+
+
 /* -------------------------------------------------------------------------------------- */
 /*! Function prototypes for engine connection/disconnection */
 typedef TSyError (*ConnectEngine_Func)    ( UI_Call_In *aCI,
@@ -627,7 +641,7 @@ typedef TSyError (*DisconnectEngine_Func)	( UI_Call_In  aCI );
 
 
 
-/* Entry point for connecting the SyncML engine from outside */
+/* Entry point for connecting the SyncML engine as client from outside */
  ENGINE_ENTRY TSyError SYSYNC_EXTERNAL(ConnectEngine)
                                           ( UI_Call_In *aCI,
                                             CVersion   *aEngVersion,
@@ -641,10 +655,30 @@ typedef TSyError (*DisconnectEngine_Func)	( UI_Call_In  aCI );
                                             CVersion    aPrgVersion,
                                             uInt16      aDebugFlags ) ENTRY_ATTR;
 
-/* Entry point for disconnecting the engine at the end */
+/* Entry point for connecting the SyncML engine as server from outside */
+ ENGINE_ENTRY TSyError SYSYNC_EXTERNAL_SRV(ConnectEngine)
+                                          ( UI_Call_In *aCI,
+                                            CVersion   *aEngVersion,
+                                            CVersion    aPrgVersion,
+                                            uInt16      aDebugFlags ) ENTRY_ATTR;
+
+ ENGINE_ENTRY TSyError SYSYNC_EXTERNAL_SRV(ConnectEngineS)
+                                          ( UI_Call_In  aCI,
+                                            uInt16      aCallbackVersion,
+                                            CVersion   *aEngVersion,
+                                            CVersion    aPrgVersion,
+                                            uInt16      aDebugFlags ) ENTRY_ATTR;
+
+
+/* Entry point for disconnecting the client engine at the end */
  ENGINE_ENTRY TSyError SYSYNC_EXTERNAL(DisconnectEngine)
                                           ( UI_Call_In  aCI         ) ENTRY_ATTR;
 
+/* Entry point for disconnecting the client engine at the end */
+ ENGINE_ENTRY TSyError SYSYNC_EXTERNAL_SRV(DisconnectEngine)
+                                          ( UI_Call_In  aCI         ) ENTRY_ATTR;
+
+
 
 #ifdef __cplusplus
   } // namespace
